
.. _pro:

Programming documentation
=========================

While *DAS* can be used via the GUI, the *das* programming module and
command-line interface provide more control, flexibility and automation:

-  `Convert your own annotation or audio data format for use with the
   GUI or training <convert.html>`__
-  `Make dataset from your own data <make_ds_notebook.html>`__
-  `Choose the structural parameters of a custom network  <structparams.html>`__
-  `Train a network and optimize network parameters <train.html>`__
-  `Infer annotations using a trained network <predict.html>`__
-  `Train and predict using a free GPU on colab <colab.html>`__
-  Details on `generating segment labels <label_segments.html>`__
-  Evaluate networks with examples for `fly song <evaluate_fly.html>`__ and
   `bird song <evaluate_bird.html>`__
-  `Annotate song in realtime for closed loop experiments <realtime.html>`__


.. toctree::
   :maxdepth: 1
   :hidden:

   :toctree: pro
   convert
   make_ds_notebook
   train
   predict
   colab
   structparams
   architecture_tuning
   experiment_tracking
   label_segments
   evaluate_fly
   evaluate_bird
   realtime

